PAWpySeed: pawpyseed.core.quadrature Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Variables
pawpyseed.core.quadrature Namespace Reference

## Variables
int | MAXSIZE = 100
| f = open("quadrature.c", "w")
list | x = []
| currstr = str(x[i][0].tolist()).replace("[", "{").replace("]", "}")

## Variable Documentation

pawpyseed.core.quadrature.currstr = str(x[i][0].tolist()).replace("[", "{").replace("]", "}")

pawpyseed.core.quadrature.f = open("quadrature.c", "w")

int pawpyseed.core.quadrature.MAXSIZE = 100

list pawpyseed.core.quadrature.x = []